summaryrefslogtreecommitdiff
path: root/src/geom/mod.rs
diff options
context:
space:
mode:
authorLaurenz <laurmaedje@gmail.com>2021-03-25 21:32:33 +0100
committerLaurenz <laurmaedje@gmail.com>2021-03-25 21:32:33 +0100
commit76fc4cca62f5b955200b2c62cc85b69eea491ece (patch)
tree5b8492268c996cf23b13e26c7a4356fbd156286d /src/geom/mod.rs
parente8057a53856dc09594c9e5861f1cd328531616e0 (diff)
Refactor alignments & directions 📐
- Adds lang function - Refactors execution context - Adds StackChild and ParChild enums
Diffstat (limited to 'src/geom/mod.rs')
-rw-r--r--src/geom/mod.rs5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/geom/mod.rs b/src/geom/mod.rs
index 5099c6b0..0031c6df 100644
--- a/src/geom/mod.rs
+++ b/src/geom/mod.rs
@@ -53,7 +53,6 @@ pub trait Switch {
/// The type of the other version.
type Other;
- /// The other version of this type based on the current layouting
- /// directions.
- fn switch(self, dirs: LayoutDirs) -> Self::Other;
+ /// The other version of this type based on the current main axis.
+ fn switch(self, main: SpecAxis) -> Self::Other;
}